@@ -10,6 +10,7 @@ from pianosdk.publisher.models.action_dto import ActionDTO
 from pianosdk.publisher.models.action_step_dto import ActionStepDTO
 from pianosdk.publisher.models.address_config import AddressConfig
 
+from pianosdk.publisher.models.address_usage_info import AddressUsageInfo
 from pianosdk.publisher.models.advanced_email_model import AdvancedEmailModel
 from pianosdk.publisher.models.advanced_options import AdvancedOptions
 from pianosdk.publisher.models.app import App
@@ -65,7 +66,12 @@ from pianosdk.publisher.models.create_billing_configuration_request import Creat
 from pianosdk.publisher.models.create_linked_term_request import CreateLinkedTermRequest
 from pianosdk.publisher.models.credit_guard_stored_fields import CreditGuardStoredFields
 from pianosdk.publisher.models.currency import Currency
+from pianosdk.publisher.models.datatrans_initiate_transaction_response import DatatransInitiateTransactionResponse
 from pianosdk.publisher.models.datatrans_properties import DatatransProperties
+from pianosdk.publisher.models.delivery_period_read_view import DeliveryPeriodReadView
+from pianosdk.publisher.models.delivery_schedule_constraint_violation_dto import DeliveryScheduleConstraintViolationDTO
+from pianosdk.publisher.models.delivery_schedule_constraint_violations_dto import DeliveryScheduleConstraintViolationsDTO
+from pianosdk.publisher.models.delivery_schedule_read_view import DeliveryScheduleReadView
 from pianosdk.publisher.models.delivery_zone import DeliveryZone
 from pianosdk.publisher.models.deployment_app import DeploymentApp
 from pianosdk.publisher.models.deployment_app_details import DeploymentAppDetails
@@ -77,6 +83,7 @@ from pianosdk.publisher.models.dns_forwarding_config import DnsForwardingConfig
 from pianosdk.publisher.models.duration import Duration
 from pianosdk.publisher.models.dynamic_subscription_access_period_info import DynamicSubscriptionAccessPeriodInfo
 from pianosdk.publisher.models.dynamic_subscription_details import DynamicSubscriptionDetails
+from pianosdk.publisher.models.dynamic_subscription_renewal_confirmation_dto import DynamicSubscriptionRenewalConfirmationDto
 from pianosdk.publisher.models.dynamic_term_access_period import DynamicTermAccessPeriod
 from pianosdk.publisher.models.easypay_configuration import EasypayConfiguration
 from pianosdk.publisher.models.edgil_payway_hosted_page_setup import EdgilPaywayHostedPageSetup
@@ -87,6 +94,7 @@ from pianosdk.publisher.models.erase_conversion import EraseConversion
 from pianosdk.publisher.models.erase_subscription import EraseSubscription
 from pianosdk.publisher.models.erase_transaction import EraseTransaction
 from pianosdk.publisher.models.erase_user import EraseUser
+from pianosdk.publisher.models.erase_user_address import EraseUserAddress
 from pianosdk.publisher.models.erase_user_payment import EraseUserPayment
 from pianosdk.publisher.models.erase_user_payment_info import EraseUserPaymentInfo
 from pianosdk.publisher.models.erase_user_response import EraseUserResponse
@@ -99,6 +107,7 @@ from pianosdk.publisher.models.experience_stat import ExperienceStat
 from pianosdk.publisher.models.experience_version import ExperienceVersion
 from pianosdk.publisher.models.export import Export
 from pianosdk.publisher.models.ext_provider_dto import ExtProviderDTO
+from pianosdk.publisher.models.extended_experience_revision import ExtendedExperienceRevision
 from pianosdk.publisher.models.external_api_configuration import ExternalAPIConfiguration
 from pianosdk.publisher.models.external_api_field import ExternalAPIField
 from pianosdk.publisher.models.external_api_property_schema import ExternalAPIPropertySchema
@@ -120,6 +129,7 @@ from pianosdk.publisher.models.import_item import ImportItem
 from pianosdk.publisher.models.import_profile import ImportProfile
 from pianosdk.publisher.models.import_section import ImportSection
 from pianosdk.publisher.models.import_user import ImportUser
+from pianosdk.publisher.models.initiate_secure_fields_params import InitiateSecureFieldsParams
 from pianosdk.publisher.models.input_stream import InputStream
 from pianosdk.publisher.models.inquiry_comment import InquiryComment
 from pianosdk.publisher.models.instrument_dto import InstrumentDTO
@@ -137,6 +147,7 @@ from pianosdk.publisher.models.licensee_representative import LicenseeRepresenta
 
 from pianosdk.publisher.models.light_experience import LightExperience
 from pianosdk.publisher.models.light_global_template import LightGlobalTemplate
+from pianosdk.publisher.models.light_offer import LightOffer
 from pianosdk.publisher.models.lightweight_churn_prevention_logic import LightweightChurnPreventionLogic
 from pianosdk.publisher.models.lightweight_experience import LightweightExperience
 from pianosdk.publisher.models.link import Link
@@ -166,6 +177,7 @@ from pianosdk.publisher.models.newscycle_configuration import NewscycleConfigura
 from pianosdk.publisher.models.newscycle_configuration_test_result import NewscycleConfigurationTestResult
 from pianosdk.publisher.models.notification import Notification
 from pianosdk.publisher.models.obi_configuration import ObiConfiguration
+from pianosdk.publisher.models.offer_list import OfferList
 from pianosdk.publisher.models.offer_model import OfferModel
 from pianosdk.publisher.models.offer_template import OfferTemplate
 from pianosdk.publisher.models.offer_template_categories import OfferTemplateCategories
@@ -178,17 +190,23 @@ from pianosdk.publisher.models.offer_template_variant import OfferTemplateVarian
 from pianosdk.publisher.models.offer_template_version import OfferTemplateVersion
 from pianosdk.publisher.models.one_source_configuration import OneSourceConfiguration
 from pianosdk.publisher.models.openpay_configuration import OpenpayConfiguration
+from pianosdk.publisher.models.page_info import PageInfo
 from pianosdk.publisher.models.pay_source_dto import PaySourceDTO
 from pianosdk.publisher.models.payee_settings_entry import PayeeSettingsEntry
+
+
+
 from pianosdk.publisher.models.payment_inquiry import PaymentInquiry
 from pianosdk.publisher.models.payment_method import PaymentMethod
 from pianosdk.publisher.models.payment_method_dto import PaymentMethodDTO
+
 from pianosdk.publisher.models.payment_provider_configuration import PaymentProviderConfiguration
 
 from pianosdk.publisher.models.paypal_express_checkout_configuration import PaypalExpressCheckoutConfiguration
 from pianosdk.publisher.models.period import Period
 from pianosdk.publisher.models.period_link import PeriodLink
 from pianosdk.publisher.models.period_link_candidate import PeriodLinkCandidate
+from pianosdk.publisher.models.period_reference_dto import PeriodReferenceDTO
 from pianosdk.publisher.models.period_settings import PeriodSettings
 from pianosdk.publisher.models.permission_dto import PermissionDTO
 from pianosdk.publisher.models.pp_configuration import PpConfiguration
@@ -220,16 +238,19 @@ from pianosdk.publisher.models.send_email_step import SendEmailStep
 from pianosdk.publisher.models.shared_account_param import SharedAccountParam
 from pianosdk.publisher.models.shared_subscription import SharedSubscription
 
+from pianosdk.publisher.models.show_option_in_channel_stats import ShowOptionInChannelStats
+from pianosdk.publisher.models.show_option_in_counters import ShowOptionInCounters
 from pianosdk.publisher.models.source import Source
 from pianosdk.publisher.models.source_eligible_term import SourceEligibleTerm
 from pianosdk.publisher.models.source_ineligible_term import SourceIneligibleTerm
 from pianosdk.publisher.models.source_term_change_variant import SourceTermChangeVariant
 from pianosdk.publisher.models.source_term_change_variants import SourceTermChangeVariants
 from pianosdk.publisher.models.split_test_object import SplitTestObject
-from pianosdk.publisher.models.spreedly_configuration import SpreedlyConfiguration
 from pianosdk.publisher.models.stripe_properties import StripeProperties
 from pianosdk.publisher.models.stripe_setup_intent_model_definition import StripeSetupIntentModelDefinition
 
+
+
 from pianosdk.publisher.models.subscription_log_item import SubscriptionLogItem
 from pianosdk.publisher.models.subscription_migration_history_dto import SubscriptionMigrationHistoryDTO
 from pianosdk.publisher.models.subscription_reallocation_error import SubscriptionReallocationError
@@ -237,6 +258,7 @@ from pianosdk.publisher.models.subscription_reallocation_validation_result impor
 
 from pianosdk.publisher.models.subscription_restrictions import SubscriptionRestrictions
 from pianosdk.publisher.models.subscription_term_change_options import SubscriptionTermChangeOptions
+
 from pianosdk.publisher.models.subscription_upgrade_status import SubscriptionUpgradeStatus
 from pianosdk.publisher.models.target_eligible_term import TargetEligibleTerm
 from pianosdk.publisher.models.target_ineligible_term import TargetIneligibleTerm
@@ -244,6 +266,8 @@ from pianosdk.publisher.models.target_term_change_variant import TargetTermChang
 from pianosdk.publisher.models.target_term_change_variants import TargetTermChangeVariants
 from pianosdk.publisher.models.target_upgrade_option import TargetUpgradeOption
 from pianosdk.publisher.models.tax_country import TaxCountry
+from pianosdk.publisher.models.tax_product_categories import TaxProductCategories
+from pianosdk.publisher.models.tax_product_category import TaxProductCategory
 from pianosdk.publisher.models.tax_support_dto import TaxSupportDTO
 from pianosdk.publisher.models.team_member import TeamMember
 from pianosdk.publisher.models.template_config import TemplateConfig
@@ -265,6 +289,7 @@ from pianosdk.publisher.models.term_conversion_dto import TermConversionDTO
 from pianosdk.publisher.models.term_conversion_data import TermConversionData
 from pianosdk.publisher.models.term_conversion_subscription import TermConversionSubscription
 from pianosdk.publisher.models.term_from import TermFrom
+from pianosdk.publisher.models.term_info import TermInfo
 from pianosdk.publisher.models.term_link import TermLink
 from pianosdk.publisher.models.term_period_reallocation import TermPeriodReallocation
 from pianosdk.publisher.models.term_reallocation import TermReallocation
@@ -283,10 +308,14 @@ from pianosdk.publisher.models.translation_stats import TranslationStats
 
 from pianosdk.publisher.models.update_access_period_params import UpdateAccessPeriodParams
 from pianosdk.publisher.models.update_billing_configuration_request import UpdateBillingConfigurationRequest
+from pianosdk.publisher.models.update_delivery_schedule_response import UpdateDeliveryScheduleResponse
 from pianosdk.publisher.models.update_linked_term_request import UpdateLinkedTermRequest
 from pianosdk.publisher.models.upgrade_checkout_flow import UpgradeCheckoutFlow
-from pianosdk.publisher.models.upgrade_offer import UpgradeOffer
+from pianosdk.publisher.models.upgrade_offer_model import UpgradeOfferModel
+from pianosdk.publisher.models.upgrade_offer_option_model import UpgradeOfferOptionModel
 from pianosdk.publisher.models.upgrade_offer_variant import UpgradeOfferVariant
+from pianosdk.publisher.models.upgrade_option import UpgradeOption
+from pianosdk.publisher.models.upgrade_options import UpgradeOptions
 from pianosdk.publisher.models.upgrade_sources import UpgradeSources
 from pianosdk.publisher.models.upgrade_subscription_step import UpgradeSubscriptionStep
 from pianosdk.publisher.models.upgrade_targets import UpgradeTargets
